pype32.datadirs

Package pype32 :: Module datadirs |
[hide private]
[frames] | no frames]

# Module datadirs

source code

Data directory classes.

Classes | [hide private]
| Directory Directory object.
| DataDirectory DataDirectory object.

Variables | [hide private]
| __revision__ = ``'``$Id$``'``
| dirs = ``[``'``EXPORT_DIRECTORY``'``,` `'``IMPORT_DIRECTORY``'``,` `'``RESOURCE_DIRE``...``
| __package__ = ``'``pype32``'``

Variables Details | [hide private]

  ### dirs Value:
      ['EXPORT_DIRECTORY',
       'IMPORT_DIRECTORY',
       'RESOURCE_DIRECTORY',
       'EXCEPTION_DIRECTORY',
       'SECURITY_DIRECTORY',
       'RELOCATION_DIRECTORY',
       'DEBUG_DIRECTORY',
       'ARCHITECTURE_DIRECTORY',
      ...